==> dokuwiki-2013.05.10.tgz: dokuwiki/lib/plugins/authmysql/lang/en/settings.php <==
<?php

$lang['server']           = 'Your MySQL server';
$lang['user']             = 'MySQL user name';
$lang['password']         = 'Password for above user';
$lang['database']         = 'Database to use';
$lang['charset']          = 'Character set used in database';
$lang['debug']            = 'Display additional debug information';
$lang['forwardClearPass'] = 'Pass user passwords as cleartext to the SQL statements below, instead of using the passcrypt option';
$lang['TablesToLock']     = 'Comma separated list of tables that should be locked on write operations';
$lang['checkPass']        = 'SQL statement for checking passwords';
$lang['getUserInfo']      = 'SQL statement for retrieving user information';
$lang['getGroups']        = 'SQL statement for retrieving a user\'s group memberships';
$lang['getUsers']         = 'SQL statement to list all users';
$lang['FilterLogin']      = 'SQL clause for filtering users by login name';
$lang['FilterName']       = 'SQL clause for filtering users by full name';
$lang['FilterEmail']      = 'SQL clause for filtering users by email address';
$lang['FilterGroup']      = 'SQL clause for filtering users by group membership';
$lang['SortOrder']        = 'SQL clause to sort users';
$lang['addUser']          = 'SQL statement to add a new user';
$lang['addGroup']         = 'SQL statement to add a new group';
$lang['addUserGroup']     = 'SQL statment to add a user to an existing group';
$lang['delGroup']         = 'SQL statement to remove a group';
$lang['getUserID']        = 'SQL statement to get the primary key of a user';
$lang['delUser']          = 'SQL statement to delete a user';
$lang['delUserRefs']      = 'SQL statement to remove a user from all groups';
$lang['updateUser']       = 'SQL statement to update a user profile';
$lang['UpdateLogin']      = 'Update clause for updating the user\'s login name';
$lang['UpdatePass']       = 'Update clause for updating the user\'s password';
$lang['UpdateEmail']      = 'Update clause for updating the user\'s email address';
$lang['UpdateName']       = 'Update clause for updating the user\'s full name';
$lang['UpdateTarget']     = 'Limit clause to identify the user when updating';
$lang['delUserGroup']     = 'SQL statement to remove a user from a given group';
$lang['getGroupID']       = 'SQL statement to get the primary key of a given group';


$lang['debug_o_0'] = 'none';
$lang['debug_o_1'] = 'on errors only';
$lang['debug_o_2'] = 'all SQL queries';

==> dokuwiki-2018.04.22ap2.tgz: dokuwiki/lib/plugins/authmysql/lang/en/settings.php <==
<?php

$lang['server']           = 'Your MySQL server';
$lang['user']             = 'MySQL user name';
$lang['password']         = 'Password for above user';
$lang['database']         = 'Database to use';
$lang['charset']          = 'Character set used in database';
$lang['debug']            = 'Display additional debug information';
$lang['forwardClearPass'] = 'Pass user passwords as cleartext to the SQL statements below, instead of using the passcrypt option';
$lang['TablesToLock']     = 'Comma separated list of tables that should be locked on write operations';
$lang['checkPass']        = 'SQL statement for checking passwords';
$lang['getUserInfo']      = 'SQL statement for retrieving user information';
$lang['getGroups']        = 'SQL statement for retrieving a user\'s group memberships';
$lang['getUsers']         = 'SQL statement to list all users';
$lang['FilterLogin']      = 'SQL clause for filtering users by login name';
$lang['FilterName']       = 'SQL clause for filtering users by full name';
$lang['FilterEmail']      = 'SQL clause for filtering users by email address';
$lang['FilterGroup']      = 'SQL clause for filtering users by group membership';
$lang['SortOrder']        = 'SQL clause to sort users';
$lang['addUser']          = 'SQL statement to add a new user';
$lang['addGroup']         = 'SQL statement to add a new group';
$lang['addUserGroup']     = 'SQL statement to add a user to an existing group';
$lang['delGroup']         = 'SQL statement to remove a group';
$lang['getUserID']        = 'SQL statement to get the primary key of a user';
$lang['delUser']          = 'SQL statement to delete a user';
$lang['delUserRefs']      = 'SQL statement to remove a user from all groups';
$lang['updateUser']       = 'SQL statement to update a user profile';
$lang['UpdateLogin']      = 'Update clause for updating the user\'s login name';
$lang['UpdatePass']       = 'Update clause for updating the user\'s password';
$lang['UpdateEmail']      = 'Update clause for updating the user\'s email address';
$lang['UpdateName']       = 'Update clause for updating the user\'s full name';
$lang['UpdateTarget']     = 'Limit clause to identify the user when updating';
$lang['delUserGroup']     = 'SQL statement to remove a user from a given group';
$lang['getGroupID']       = 'SQL statement to get the primary key of a given group';


$lang['debug_o_0'] = 'none';
$lang['debug_o_1'] = 'on errors only';
$lang['debug_o_2'] = 'all SQL queries';
